@@ -1,6 +1,6 @@
 from importlib.metadata import version
 
-from .processors import KNP, Jumanpp, RegexSenter
+from .processors import KNP, KWJA, Jumanpp, RegexSenter
 from .units import BasePhrase, Clause, Document, Morpheme, Phrase, Sentence
 
 __version__ = version("rhoknp")
@@ -10,6 +10,7 @@ __all__ = [
     "RegexSenter",
     "Jumanpp",
     "KNP",
+    "KWJA",
     "Document",
     "Sentence",
     "Clause",
