@@ -1,6 +1,6 @@
 from .argument import Argument, ArgumentType, EndophoraArgument, ExophoraArgument
 from .coreference import Entity, EntityManager
-from .discourse_relation import DiscourseRelation, DiscourseRelationList
+from .discourse import DiscourseRelation, DiscourseRelationLabel, DiscourseRelationTag
 from .exophora import ExophoraReferent, ExophoraReferentType
 from .pas import Pas
 from .predicate import Predicate
@@ -21,5 +21,6 @@ __all__ = [
     "RelTagList",
     "RelMode",
     "DiscourseRelation",
-    "DiscourseRelationList",
+    "DiscourseRelationLabel",
+    "DiscourseRelationTag",
 ]
