@@ -3,16 +3,80 @@ from dataclasses import dataclass
 from enum import Enum
 from typing import ClassVar, List, Optional
 
+CASE_TYPES = [
+    "ガ",
+    "デ",
+    "ト",
+    "ニ",
+    "ノ",
+    "ヘ",
+    "ヲ",
+    "カラ",
+    "ガ２",
+    "ノ？",
+    "マデ",
+    "ヨリ",
+    "トイウ",
+    "トシテ",
+    "トスル",
+    "ニオク",
+    "ニシテ",
+    "ニツク",
+    "ニトル",
+    "ニヨル",
+    "マデニ",
+    "ニオイテ",
+    "ニカワル",
+    "ニソッテ",
+    "ニツイテ",
+    "ニトッテ",
+    "ニムケテ",
+    "ニムケル",
+    "ニヨッテ",
+    "ニヨラズ",
+    "ニアワセテ",
+    "ニカギッテ",
+    "ニカギラズ",
+    "ニカランデ",
+    "ニカワッテ",
+    "ニカンシテ",
+    "ニカンスル",
+    "ニクラベテ",
+    "ニクワエテ",
+    "ニタイシテ",
+    "ニタイスル",
+    "ニツヅイテ",
+    "ニナランデ",
+    "ヲツウジテ",
+    "ヲツウジル",
+    "ヲノゾイテ",
+    "ヲフクメテ",
+    "ヲメグッテ",
+    "ニトモナッテ",
+    "ニモトヅイテ",
+    "無",
+    "修飾",
+    "判ガ",
+    "時間",
+    "外の関係",
+]
+CASE_TYPES += [case + "≒" for case in CASE_TYPES]
+
+COREF_TYPES = ["=", "=構", "=役"]
+COREF_TYPES += [coref + "≒" for coref in COREF_TYPES]
+
 
 class RelMode(Enum):
     """同一の基本句に同一タイプの関係タグが複数付いている場合にそれらの関係を表す列挙体．
 
     .. note::
-        * AND: 関係の対象が並列である．
+        各関係タグの具体例は以下の通りである：
+
+        * AND
             (例) 太郎と花子が学校から<帰った> (ガ格:太郎, ガ格:花子 [and])
-        * OR: 「AかB」のように意味的に or である．
+        * OR
             (例) 私は田園調布か国立に<住みたい> (ガ格:私, ニ格:田園調布, ニ格:国立 [or])
-        * AMBIGUOUS:いずれの解釈も妥当であり，文脈から判断ができない．
+        * AMBIGUOUS
             (例) 高知県の橋本知事は…国籍条項を<撤廃する>方針を明らかにした (ガ格:高知県, ガ格:橋本知事 [？], ガ格:不特定:人 [？], ヲ格:条項, 外の関係:方針)
 
     .. note::
@@ -20,9 +84,9 @@ class RelMode(Enum):
             (例) 太郎は一人で<立っていた> (ガ格:太郎, デ格:一人, デ格:なし [？])
     """
 
-    AND = "AND"
-    OR = "OR"
-    AMBIGUOUS = "？"
+    AND = "AND"  #: 関係の対象が並列である．
+    OR = "OR"  #: 「AかB」のように意味的に or である．
+    AMBIGUOUS = "？"  #: いずれの解釈も妥当であり，文脈から判断ができない．
 
 
 @dataclass
