@@ -1,5 +1,6 @@
 import logging
-from subprocess import PIPE, Popen, run
+from subprocess import PIPE, Popen
+from threading import Lock
 from typing import List, Optional, Union
 
 from rhoknp.processors.processor import Processor
@@ -18,18 +19,12 @@ class Jumanpp(Processor):
         senter: 文分割器のインスタンス．文分割がまだなら，先にこのインスタンスを用いて文分割する．
             未設定なら RegexSenter を使って文分割する．
 
-    Attributes:
-        executable: Juman++ のパス．
-        options: Juman++ のオプション．
-        senter: 文分割器のインスタンス．文分割がまだなら，先にこのインスタンスを用いて文分割する．
-            未設定なら RegexSenter を使って文分割する．
-
     Example:
 
         >>> from rhoknp import Jumanpp
         <BLANKLINE>
         >>> jumanpp = Jumanpp()
-        >>> sentence = jumanpp.apply("電気抵抗率は、どんな材料が電気を通しにくいかを比較するために、用いられる物性値である。")
+        >>> document = jumanpp.apply("電気抵抗率は電気の通しにくさを表す物性値である。")
     """
 
     def __init__(
@@ -38,9 +33,15 @@ class Jumanpp(Processor):
         options: Optional[List[str]] = None,
         senter: Optional[Processor] = None,
     ) -> None:
-        self.executable = executable
-        self.options = options
+        self.executable = executable  #: Juman++ のパス．
+        self.options = options  #: Juman++ のオプション．
         self.senter = senter
+        self._proc: Optional[Popen] = None
+        try:
+            self._proc = Popen(self.run_command, stdout=PIPE, stdin=PIPE, encoding="utf-8")
+        except Exception as e:
+            logger.warning(f"failed to start Juman++: {e}")
+        self._lock = Lock()
 
     def __repr__(self) -> str:
         arg_string = f"executable={repr(self.executable)}"
@@ -50,6 +51,10 @@ class Jumanpp(Processor):
             arg_string += f", senter={repr(self.senter)}"
         return f"{self.__class__.__name__}({arg_string})"
 
+    def is_available(self) -> bool:
+        """Jumanpp が利用可能であれば True を返す．"""
+        return self._proc is not None and self._proc.poll() is None
+
     def apply_to_document(self, document: Union[Document, str]) -> Document:
         """文書に Jumanpp を適用する．
 
@@ -60,6 +65,12 @@ class Jumanpp(Processor):
             文分割がまだなら，先に初期化時に設定した senter で文分割する．
             未設定なら RegexSenter で文分割する．
         """
+        if not self.is_available():
+            raise RuntimeError("Juman++ is not available.")
+        assert self._proc is not None
+        assert self._proc.stdin is not None
+        assert self._proc.stdout is not None
+
         if isinstance(document, str):
             document = Document(document)
 
@@ -70,9 +81,18 @@ class Jumanpp(Processor):
                 self.senter = RegexSenter()
             document = self.senter.apply_to_document(document)
 
-        with Popen(self.run_command, stdout=PIPE, stdin=PIPE, encoding="utf-8") as p:
-            jumanpp_text, _ = p.communicate(input=document.to_raw_text())
-        return Document.from_jumanpp(jumanpp_text)
+        with self._lock:
+            jumanpp_text = ""
+            for sentence in document.sentences:
+                self._proc.stdin.write(sentence.to_raw_text())
+                self._proc.stdin.flush()
+                while self.is_available():
+                    line = self._proc.stdout.readline()
+                    jumanpp_text += line
+                    if line.strip() == Sentence.EOS_PAT:
+                        break
+                self._proc.stdout.flush()
+            return Document.from_jumanpp(jumanpp_text)
 
     def apply_to_sentence(self, sentence: Union[Sentence, str]) -> Sentence:
         """文に Jumanpp を適用する．
@@ -80,22 +100,26 @@ class Jumanpp(Processor):
         Args:
             sentence: 文．
         """
+        if not self.is_available():
+            raise RuntimeError("Juman++ is not available.")
+        assert self._proc is not None
+        assert self._proc.stdin is not None
+        assert self._proc.stdout is not None
+
         if isinstance(sentence, str):
             sentence = Sentence(sentence)
 
-        with Popen(self.run_command, stdout=PIPE, stdin=PIPE, encoding="utf-8") as p:
-            jumanpp_text, _ = p.communicate(input=sentence.to_raw_text())
-        return Sentence.from_jumanpp(jumanpp_text)
-
-    def is_available(self) -> bool:
-        """Jumanpp が利用可能であれば True を返す．"""
-        try:
-            p = run(self.version_command, stdout=PIPE, stdin=PIPE, encoding="utf-8")
-            logger.info(p.stdout.strip())
-            return True
-        except Exception as e:
-            logger.warning(e)
-            return False
+        with self._lock:
+            jumanpp_text = ""
+            self._proc.stdin.write(sentence.to_raw_text())
+            self._proc.stdin.flush()
+            while self.is_available():
+                line = self._proc.stdout.readline()
+                jumanpp_text += line
+                if line.strip() == Sentence.EOS_PAT:
+                    break
+            self._proc.stdout.flush()
+            return Sentence.from_jumanpp(jumanpp_text)
 
     @property
     def run_command(self) -> List[str]:
@@ -104,8 +128,3 @@ class Jumanpp(Processor):
         if self.options:
             command += self.options
         return command
-
-    @property
-    def version_command(self) -> List[str]:
-        """バージョン確認時に実行するコマンド．"""
-        return [self.executable, "-v"]
