@@ -4,15 +4,19 @@ from typing import Any, Optional, Sequence
 
 class Unit(ABC):
     def __init__(self) -> None:
-        self._index: Optional[int] = None
-
+        self.index: int = -1
         self._text: Optional[str] = None
 
+    def __post_init__(self) -> None:
+        if self.child_units is not None:
+            for child_unit in self.child_units:
+                child_unit.__post_init__()
+
     def __str__(self) -> str:
         return self.text
 
     def __repr__(self) -> str:
-        return f"{self.__class__.__name__}(index={repr(self.index)}, text={repr(self.text)})"
+        return f"<{self.__module__}.{self.__class__.__name__}: {repr(self.index)}, {repr(self.text)}>"
 
     def __eq__(self, other: Any) -> bool:
         if isinstance(other, type(self)) is False:
@@ -30,15 +34,6 @@ class Unit(ABC):
     def child_units(self) -> Optional[Sequence["Unit"]]:
         raise NotImplementedError
 
-    @property
-    def index(self) -> int:
-        assert self._index is not None
-        return self._index
-
-    @index.setter
-    def index(self, index: int) -> None:
-        self._index = index
-
     @property
     def text(self) -> str:
         if self._text is not None:
